"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isAUID = exports.generateAUID_dom = exports.generateAUID = void 0;
const crypto_1 = require("crypto");
/**
 * Generates a crytografically strong AUID
 *
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
function generateAUID() {
    const bytes = (0, crypto_1.randomBytes)(32).toString('hex'); // 64 hex characters
    return `${bytes.slice(0, 16)}-${bytes.slice(16, 32)}-${bytes.slice(32, 48)}-${bytes.slice(48, 64)}`;
}
exports.generateAUID = generateAUID;
;
/**
 * Generates a crytografically strong AUID **inside of the browser environment**
 *
 * With `(2 ^ 4) ^ (16*4)` or `2 ^ 256` or `1.1579209e+77` possible combinations
 */
function generateAUID_dom() {
    const bytes = new Uint8Array(32);
    crypto.getRandomValues(bytes);
    const b = Buffer.from(bytes).toString("hex");
    return `${b.slice(0, 16)}-${b.slice(16, 32)}-${b.slice(32, 48)}-${b.slice(48, 64)}`;
}
exports.generateAUID_dom = generateAUID_dom;
;
/**
 * Fullproof regex for AUIDs
 */
exports.isAUID = new RegExp(/^[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}-[a-f0-9]{16}$/);
